import ConfigParser
import sys

__author__ = 'pasuder'


class Config(object):
    def __init__(self, *args):
        self.__config = ConfigParser.ConfigParser()
        self.add_config_ini(*args)

    def __getattr__(self, name):
        # noinspection PyBroadException
        try:
            return self.__config.get('default', name)
        except Exception as n_exp:
            print('Cannot found value for %s in config: %s\n' % (name, n_exp))
            return None

    def set_attr(self, key, value):
        # noinspection PyBroadException
        try:
            self.__config.set('default', key, str(value))
        except Exception as n_exp:
            print('Cannot set value %s for %s to config: %s\n' % (value, key, n_exp))

    def add_config_ini(self, *args):
        map(lambda config_file_path: self.__config.read(config_file_path), args)


sys.modules[__name__] = Config()


def add_config_ini(*args):
    sys.modules[__name__].add_config_ini(*args)


def set_attr(*args):
    sys.modules[__name__].set_attr(*args)



import os

from python_project_skeleton.tools import config


pwd = os.path.dirname(os.path.abspath(__file__))
config.add_config_ini('%s/main.ini' % pwd)

if __name__ == '__main__':
    print('Hello World!\nValue for NAME is %s.' % config.NAME)



# coding=utf-8
# !/usr/bin/env python

try:
    from setuptools import setup
except ImportError:
    print('No setuptools installed, use distutils')
    from distutils.core import setup

with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name='python_project_skeleton',
    packages=[
        'python_project_skeleton',
        'python_project_skeleton.tools',
        'python_project_skeleton.tests'
    ],
    package_dir={
        'python_project_skeleton': 'src/python_project_skeleton',
        'python_project_skeleton.tools': 'src/python_project_skeleton/tools',
        'python_project_skeleton.tests': 'src/python_project_skeleton/tests'
    },
    package_data={'': [
        'src/python_project_skeleton/main.ini'
    ]},
    data_files=[
        ('', [
            'src/python_project_skeleton/main.ini'
        ]),
    ],
    test_suite="python_project_skeleton.tests",
    include_package_data=True,
    install_requires=required,
    version='1.3',
    description='python project skeleton',
    author=u'Paweł Suder',
    author_email='pawel@suder.info',
    url='http://github.com/pasuder/python-project-skeleton',
    download_url='http://github.com/pasuder/python-project-skeleton',
    keywords=[
        'skeleton'
    ],
    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 4 - Beta',
        'Environment :: Other Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    long_description='''\
'''
)
